<?php

	// ライブラリを読み込む
	require_once './autoload.php' ;

	// クライアントID
	$client_id = '...@developer.gserviceaccount.com' ;

	// ビューID
	$view_id = '86695217' ;

	// 秘密キーファイルの読み込み
	$private_key = @file_get_contents( './Syncer_Analytics-208312d9d56b.p12' ) ;

	// 取得する期間 (YYYY-MM-DD)
	$from = date( 'Y-m-d' , strtotime( '-1 month' ) ) ;		// 対象開始日
	$to = date( 'Y-m-d' ) ;		// 対象終了日

	// 取得するデータの組み合わせ (複数の場合は[,]で区切る)
	$dimensions = 'ga:pageTitle, ga:pagePath' ;		// ディメンション
	$metrics = 'ga:sessions , ga:users , ga:pageviews , ga:pageviewsPerSession , ga:avgSessionDuration , ga:bounceRate , ga:percentNewSessions' ;		// メトリクス

	//オプション
	$option = array(
		'dimensions' => $dimensions ,
		'max-results' => 10 ,
//		'sort' => '-ga:pageviews' ,
//		'start-index' => 11,	// 取得開始位置
	) ;

	// トークンのセット
	if( isset( $_SESSION['service_token'] ) )
	{
		$client->setAccessToken( $_SESSION['service_token'] ) ;
	}

	// スコープのセット (読み込みオンリー)
	$scopes = array( 'https://www.googleapis.com/auth/analytics.readonly' ) ;

	// クレデンシャルの作成
	$credentials = new Google_Auth_AssertionCredentials( $client_id , $scopes , $private_key ) ;

	// Googleクライアントのインスタンスを作成
	$client = new Google_Client() ;
	$client->setAssertionCredentials( $credentials ) ;

	// トークンのリフレッシュ
	if( $client->getAuth()->isAccessTokenExpired() )
	{
		$client->getAuth()->refreshTokenWithAssertion( $credentials ) ;
	}

	// セッションの設定
	$_SESSION['service_token'] = $client->getAccessToken() ;

	// Analyticsのインスタンスを作成
	$analytics = new Google_Service_Analytics( $client ) ;

	// データの取得
	$obj = $analytics->data_ga->get( 'ga:' . $view_id , $from , $to , $metrics , $option ) ;

	// JSONデータに変換
	$json = json_encode( $obj ) ;

	// HTML用
	$html = '' ;

	// 実行結果を出力
	$html .= '<h2>実行結果</h2>' ;
	$html .= '<p>直近1ヶ月間(' . date( 'Y/m/d' , strtotime( $from ) ) . '〜' . date( 'Y/m/d' , strtotime( $to ) ) . ')のユーザーサマリーを取得しました。<mark>値はサンプル用のダミーです。</mark></p>' ;

	// エラー判定
	if( !isset($obj->rows) )
	{
		$html .= '<p><mark>データを取得できませんでした…。</mark></p>' ;
	}
	else
	{
		// 各データ
		$sessions = $obj->totalsForAllResults['ga:sessions'] ;		// セッション
		$users = $obj->totalsForAllResults['ga:users'] ;		// ユーザー
		$pageviews = $obj->totalsForAllResults['ga:pageviews'] ;		// ページビュー数
		$pageviewsPerSession = $obj->totalsForAllResults['ga:pageviewsPerSession'] ;		// ページ/セッション
		$avgSessionDuration = $obj->totalsForAllResults['ga:avgSessionDuration'] ;		// 平均セッション時間
		$bounceRate = $obj->totalsForAllResults['ga:bounceRate'] ;		// 直帰率
		$percentNewSessions = $obj->totalsForAllResults['ga:percentNewSessions'] ;		// 新規セッション率

		// 出力
		$html .= '<dl>' ;
		$html .= 	'<dt>セッション</dt>' ;
		$html .= 		'<dd>' . number_format( $sessions ) . '</dd>' ;
		$html .= 	'<dt>ユーザー</dt>' ;
		$html .= 		'<dd>' . number_format( $users ) . '</dd>' ;
		$html .= 	'<dt>ページビュー数</dt>' ;
		$html .= 		'<dd>' . number_format( $pageviews ) . '</dd>' ;
		$html .= 	'<dt>ページ/セッション</dt>' ;
		$html .= 		'<dd>' . round( $pageviewsPerSession , 2 ) . '%</dd>' ;
		$html .= 	'<dt>平均セッション時間</dt>' ;
		$html .= 		'<dd>' . sprintf( '%02d' , floor( $avgSessionDuration / 60 ) ) . ':' . sprintf( '%02d' , floor( $avgSessionDuration % 60 ) ) . '</dd>' ;
		$html .= 	'<dt>直帰率</dt>' ;
		$html .= 		'<dd>' . round( $bounceRate , 2 ) . '%</dd>' ;
		$html .= 	'<dt>新規セッション率</dt>' ;
		$html .= 		'<dd>' . round( $percentNewSessions , 2 ) . '%</dd>' ;
		$html .= '</dl>' ;
	}

	// 取得したデータ
	$html .= '<h2>取得したデータ(JSON)</h2>' ;
	$html .= 	'<textarea rows="8">' . $json . '</textarea>' ;

?><!DOCTYPE html>
<html>
	<head>
		<meta charset="UTF-8">
		<meta name="robots" content="noindex,nofollow">

		<!-- ビューポートの設定 -->
		<meta name="viewport" content="width=device-width, initial-scale=1.0">

		<title>Google Analytics APIでユーザーサマリーを取得するサンプルデモ</title><!-- 

/********************************************************************************

	SYNCER 〜 知識、感動をみんなと同期(Sync)するブログ

	* 配布場所
	https://syncer.jp/google-analytics-api-tutorial

	* 動作確認
	https://syncer.jp/google-analytics-api-tutorial/demo/analytics-user-summary.php

	* 最終更新日時
	2015/09/08 03:35

	* 作者
	あらゆ

	** 連絡先
	Twitter: https://twitter.com/arayutw
	Facebook: https://www.facebook.com/arayutw
	Google+: https://plus.google.com/114918692417332410369/
	E-mail: info@syncer.jp

	※ バグ、不具合の報告、提案、ご要望など、お待ちしております。
	※ 申し訳ありませんが、ご利用者様、個々の環境における問題はサポートしていません。

********************************************************************************/

		-->
	</head>
<body>



<?php echo $html ?>


<p style="text-align:center"><a href="https://syncer.jp/google-analytics-api-tutorial">配布元: Syncer</a></p>






</body>
</html>
