<?php

	// ライブラリを読み込む
	require_once './autoload.php' ;

	// クライアントID
	$client_id = '...@developer.gserviceaccount.com' ;

	// ビューID
	$view_id = '86695217' ;

	// 秘密キーファイルの読み込み
	$private_key = @file_get_contents( './Syncer_Analytics-208312d9d56b.p12' ) ;

	// 取得する期間 (YYYY-MM-DD)
	$from = date( 'Y-m-d' , strtotime( '-1 day' ) ) ;		// 対象開始日
	$to = date( 'Y-m-d' ) ;		// 対象終了日

	// 取得するデータの組み合わせ (複数の場合は[,]で区切る)
	$dimensions = 'ga:pageTitle, ga:pagePath, ga:date' ;		// ディメンション
	$metrics = 'ga:pageviews' ;		// メトリクス

	//オプション
	$option = array(
		'dimensions' => $dimensions ,
		'max-results' => 10 ,
		'sort' => '-ga:pageviews' ,
//		'start-index' => 11,	// 取得開始位置
	) ;

	// トークンのセット
	if( isset( $_SESSION['service_token'] ) )
	{
		$client->setAccessToken( $_SESSION['service_token'] ) ;
	}

	// スコープのセット (読み込みオンリー)
	$scopes = array( 'https://www.googleapis.com/auth/analytics.readonly' ) ;

	// クレデンシャルの作成
	$credentials = new Google_Auth_AssertionCredentials( $client_id , $scopes , $private_key ) ;

	// Googleクライアントのインスタンスを作成
	$client = new Google_Client() ;
	$client->setAssertionCredentials( $credentials ) ;

	// トークンのリフレッシュ
	if( $client->getAuth()->isAccessTokenExpired() )
	{
		$client->getAuth()->refreshTokenWithAssertion( $credentials ) ;
	}

	// セッションの設定
	$_SESSION['service_token'] = $client->getAccessToken() ;

	// Analyticsのインスタンスを作成
	$analytics = new Google_Service_Analytics( $client ) ;

	// データの取得
	$obj = $analytics->data_ga->get( 'ga:' . $view_id , $from , $to , $metrics , $option ) ;

	// JSONデータに変換
	$json = json_encode( $obj ) ;

	// HTML用
	$html = '' ;

	// 実行結果を出力
	$html .= '<h2>実行結果</h2>' ;
	$html .= '<p><b>' . date( 'Y/m/d' , strtotime( $from ) ) . '</b>の、ページビューのデイリーランキングを取得してみました。<mark>値はサンプル用のダミーです。</mark></p>' ;

	// エラー判定
	if( !isset($obj->rows) )
	{
		$html .= '<p><mark>データを取得できませんでした…。</mark></p>' ;
	}
	else
	{
		$html .= '<ol>' ;

		// 解析
		for( $i=0 , $l=count( $obj->rows ) ; $l > $i ; $i++ )
		{
			// エイリアス
			$item = $obj->rows[ $i ] ;

			// 出力
			$html .= '<li><a href="' . $item[1] . '" target="_blank">' . $item[0] . '</a> (' . number_format( $item[3] ) . 'PV)</li>' ;
		}

		$html .= '</ol>' ;
	}

	// 取得したデータ
	$html .= '<h2>取得したデータ(JSON)</h2>' ;
	$html .= 	'<textarea rows="8">' . $json . '</textarea>' ;

?><!DOCTYPE html>
<html>
	<head>
		<meta charset="UTF-8">
		<meta name="robots" content="noindex,nofollow">

		<!-- ビューポートの設定 -->
		<meta name="viewport" content="width=device-width, initial-scale=1.0">

		<title>Google Analytics APIでデータを取得するサンプルデモ</title><!-- 

/********************************************************************************

	SYNCER 〜 知識、感動をみんなと同期(Sync)するブログ

	* 配布場所
	https://syncer.jp/google-analytics-api-tutorial

	* 動作確認
	https://syncer.jp/google-analytics-api-tutorial/demo/analytics.php

	* 最終更新日時
	2015/09/08 03:36

	* 作者
	あらゆ

	** 連絡先
	Twitter: https://twitter.com/arayutw
	Facebook: https://www.facebook.com/arayutw
	Google+: https://plus.google.com/114918692417332410369/
	E-mail: info@syncer.jp

	※ バグ、不具合の報告、提案、ご要望など、お待ちしております。
	※ 申し訳ありませんが、ご利用者様、個々の環境における問題はサポートしていません。

********************************************************************************/

		-->
	</head>
<body>



<?php echo $html ?>


<p style="text-align:center"><a href="https://syncer.jp/google-analytics-api-tutorial">配布元: Syncer</a></p>






</body>
</html>
